.. _notebooks-label:

=========
Notebooks
=========

Altitude Control of a Quadcopter
================================

    * Basics - StateSpace
        * Demonstrates how to create StateSpace controller, and how to design a control loop with the API
        * The importance of the modelling parameter is indicated along with possibly scenarios
        * See how ADRC rejects disturbances.

        .. image:: https://mybinder.org/badge_logo.svg
            :target: https://mybinder.org/v2/gh/onguntoglu/pyadrc/master?filepath=docs%2Fnotebooks%2Fquadcopter_basic.ipynb

    * Closed-loop dynamics
        * Examines how controller and observer poles are placed using bandwidth parametrization
        * The effects of noise are investigated.
        * Half-gain tuning is introduced.

    * Magnitude and rate limiters
        * Limiters and their significance for practical implementation are discussed. 


